"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const debug_1 = require("./debug");
const validate_1 = require("./validate");
// no header, format: CSV, filter
const args = (pid) => ['/NH', '/FO', 'CSV', '/FI', `PID eq ${pid}`];
const spawnOptions = {
    stdio: [0, null, 2],
    encoding: 'utf8',
};
function isActive(pid) {
    return new Promise((resolve, reject) => {
        if (!validate_1.default(pid))
            return resolve(false);
        debug_1.default('tasklist', args(pid));
        const p = child_process_1.spawn('tasklist', args(pid), spawnOptions);
        p.on('close', code => {
            if (code !== 0)
                reject(new Error(`tasklist exited with code ${code}`));
        });
        p.stdout.on('data', (stdout) => {
            resolve(!stdout.includes('No tasks are running'));
        });
    });
}
exports.isActive = isActive;
function isActiveSync(pid) {
    if (!validate_1.default(pid))
        return false;
    debug_1.default('tasklist sync', args(pid));
    const result = child_process_1.spawnSync('tasklist', args(pid), spawnOptions);
    if (result.error)
        throw result.error;
    if (result.status !== 0)
        throw new Error(`tasklist exited with code ${status}`);
    return !result.stdout.includes('No tasks are running');
}
exports.isActiveSync = isActiveSync;
